==> nocc-1.9.5.txz: usr/local/www/nocc/lang/ne.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ne.php 2602 2014-03-31 22:00:26Z siebrand $
 */
/** Nepali (नेपाली)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Krish Dulal
 * @author RajeshPandey
 * @author सरोज कुमार ढकाल
 */

$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'प्रवेशको मान खाली छ';
$err_passwd_empty = 'प्रवेशशब्द मान खाली छ';
$alt_delete = 'छानिएका सन्देशहरु मेट्ने';
$alt_delete_one = 'सन्देश मेट्ने';
$alt_new_msg = 'नयाँ सन्देशहरू';
$alt_reply = 'लेखकलाई जवाफ लेख्ने';
$alt_reply_all = 'सबैको जवाफलेख्ने';
$alt_forward = 'अगाडि बढाउने';
$alt_next = 'पछिको';
$alt_prev = 'अघिको';
$title_next_page = 'पछिको पृष्ठ';
$title_prev_page = 'अघिको पृष्ठ';
$title_next_msg = 'पछिको सन्देश';
$title_prev_msg = 'अघिको सन्देश';
$html_theme_label = 'विषय सार:';
$html_welcome = ' %1$s मा स्वागत छ';
$html_login = 'प्रवेश गर्ने';
$html_user_label = 'प्रयोगकर्ता :';
$html_passwd_label = 'प्रवेशशव्द:';
$html_submit = 'बुझाउने';
$html_help = 'सहायता';
$html_server_label = 'सर्भर:';
$html_wrong = 'प्रवेश या प्रवेशशव्द गलत छ';
$html_retry = 'पुन: प्रयास गर्ने';
$html_remember = 'स्थिती सम्झने';
$html_lang_label = 'भाषा:';
$html_msgperpage_label = 'प्रति पृष्ठ सन्देश:';
$html_preferences = 'अभिरुचीहरु';
$html_full_name_label = 'पूरा नाम:';
$html_email_address_label = 'इमेल ठेगाना:';
$html_bccself = 'बि सि सि प्रतिलिपि आफैलाइ';
$html_hide_addresses = 'ठेगाना लुकाउने';
$html_outlook_quoting = 'Outlook जस्तो कोटिङ्ग';
$html_reply_to = 'लाई जवाफ दिने';
$html_use_signature = 'हस्ताक्षर प्रयोग गर्ने';
$html_signature = 'हस्ताक्षर';
$html_signature_label = 'हस्ताक्षर:';
$html_reply_leadin_label = ' Leadin जवाफ लेख्ने:';
$html_prefs_updated = 'अभिरुचीहरु अध्यावधिक गरियो';
$html_manage_folders_link = ' IMAP फोल्डरहरु व्यवस्थापन गर्ने';
$html_manage_filters_link = 'ईमेल फिल्टरहरु व्यवस्तापन गर्ने';
$html_use_graphical_smilies = 'ग्राफिकल स्माइलीहरु प्रयोगगर्ने';
$html_sent_folder_label = 'पठाइएको इमेलहरु निश्चित फोल्डरमा प्रतिलिपी गर्ने';
$html_trash_folder_label = 'मेटिएका इमेलहरु निश्चित फोल्डरमा प्रतिलिपी गर्ने';
$html_colored_quotes = 'रंगाइएका कोटहरु';
$html_display_struct = 'संरचित पाठहरु देखाउने';
$html_send_html_mail = 'इमेलहरु HTML ढाँचामा पठाउने';
$html_folders = 'फोल्डरहरु';
$html_folders_create_failed = 'फोल्डर श्रृजना गर्न सकिएन !';
$html_folders_sub_failed = 'फोल्डरको ग्राह्यता प्राप्त गर्न सकिएन !';
$html_folders_unsub_failed = 'फोल्डरको ग्राह्यता बदर गर्न सकिएन !';
$html_folders_rename_failed = 'फोल्डर पुन: नामाकरण गर्न सकिएन !';
$html_folders_updated = 'फोल्षरहरु पुन: नामाकरण गरिए';
$html_folder_subscribe = 'ग्राह्यता';
$html_folder_rename = 'पुन: नामाकरण';
$html_folder_create = 'नाम गरिएको नयाँ फोल्डर श्रृजना गर्ने';
$html_folder_remove = 'बाट ग्राह्यता बदर गर्ने';
$html_folder_delete = 'मेट्ने';
$html_folder_to = 'लाई';
$html_filter_remove = 'मेट्ने';
$html_filter_body = 'सन्देश मूल भाग';
$html_filter_subject = 'सन्देश विषय';
$html_filter_to = 'लाई मान';
$html_filter_cc = 'Cc मान';
$html_filter_from = 'देखी मान';
$html_filter_change_tip = 'फिल्टर परिवर्तनको लागि अधिलेखन गर्नुहोस ।';
$html_reapply_filters = 'सबै फिल्टरको जवाफ लेख्ने';
$html_filter_contains = 'मा निहित';
$html_filter_name = 'फिल्टर नाम';
$html_filter_action = 'फिल्टर कार्य';
$html_filter_moveto = 'मा सार्ने';
$html_select_one = '--एक छान्नुहोस--';
$html_and = 'र';
$html_new_msg_in = 'नयाँ सन्देशहरू';
$html_or = 'वा';
$html_move = 'सार्ने';
$html_copy = 'प्रतिलिपी';
$html_messages_to = 'छानिएका सन्देशहरु';
$html_gotopage = 'पृष्ठमा जाने';
$html_gotofolder = 'फोल्डरमा जाने';
$html_other_folders = 'फो्डर सुची';
$html_page = 'पृष्ठ';
$html_of = 'को';
$html_view_header = 'शिर्षक प्रदर्शन गर्ने';
$html_remove_header = 'शिर्षक प्रदर्शन नगर्ने';
$html_inbox = 'पत्र मञ्जुषा';
$html_new_msg = 'लेख्ने';
$html_reply = 'जवाफ';
$html_reply_short = 'पुन:';
$html_reply_all = 'सबै जवाफ फर्काउने';
$html_forward = 'अगाडि बढाउने';
$html_forward_short = 'Fwd:';
$html_forward_info = 'अगाडि पठाएका सन्देशहरु यस सन्देशमा जोडेर पठाइने छ ।';
$html_delete = 'मेटाउने';
$html_new = 'नयाँ';
$html_mark = 'मेटाउने';
$html_att_label = 'यसमा जोडिएको:';
$html_atts_label = 'यसमा जोडिएकाहरु:';
$html_unknown = '[अज्ञात]';
$html_part_x = 'भाग %s';
$html_attach = 'जोड्ने';
$html_attach_forget = 'तपाईको फाइल पठाउनु अघि जोड्नु पर्ने छ!';
$html_attach_delete = 'छानिएको हटाउने';
$html_attach_none = 'जोड्नको लागि कुनै फाइल छान्नु पर्छ !';
$html_sort_by = 'को आधारमा सुचीकरण';
$html_sort = 'सुचीकरण';
$html_from = 'देखि';
$html_from_label = 'देखि:';
$html_subject = 'विषय';
$html_subject_label = 'विषय:';
$html_date = 'मिति';
$html_date_label = 'मिति:';
$html_sent_label = 'पठाइएको:';
$html_wrote = 'लेख्नु भएको थियो';
$html_size = 'आकार';
$html_totalsize = 'पूरा आकार';
$html_kb = 'केबि';
$html_mb = 'एमबि';
$html_gb = 'जिबि';
$html_bytes = 'बाइटहरु';
$html_filename = 'फाइल नाम';
$html_to = 'लाई';
$html_to_label = 'लाई:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'विषय बिना';
$html_send = 'पठाउने';
$html_cancel = 'बदर गर्ने';
$html_no_mail = 'सन्देश बिना।';
$html_logout = 'बाहिरिने';
$html_msg = 'सन्देश';
$html_msgs = 'सन्देशहरु';
$html_configuration = 'यो सर्भर राम्ररी मिलाइएको छैन !';
$html_priority = 'प्राथमिकता';
$html_priority_label = 'प्राथमिकता:';
$html_lowest = 'अति न्युन';
$html_low = 'न्युन';
$html_normal = 'सामान्य';
$html_high = 'उच्च';
$html_highest = 'अति उच्च';
$html_flagged = 'फ्ल्याग गरिएको';
$html_spam = 'स्प्याम';
$html_spam_warning = 'यस संदेश लाइ स्प्याम को रूप मा वर्गीकृत गरिएको छ।';
$html_receipt = 'फिर्ते रसिदको लागि अनुरोध गर्ने';
$html_select = 'छान्ने';
$html_select_all = 'छानिएको उल्ट्याउने';
$html_select_contacts = 'सम्पर्क छान्ने';
$html_loading_image = 'तस्विर लोड गर्दै';
$html_send_confirmed = 'तपाईको इमेल प्रेषणको लागि स्विकारिएको छ';
$html_no_sendaction = 'कुनै पनि कार्य खुलाइएको छैन । जाभा स्क्रिप्ट सक्षम पार्नुहोस् ।';
$html_error_occurred = 'एक त्रुटि भयो ।';
$html_prefs_file_error = 'अभीरुची फाइलहरु लेखनको लागि खोल्न असमर्थ ।';
$html_wrap = 'पठाउन लागिएको सन्देशमा र्‌याप गर्नुपर्ने क्यारेक्टरहरु :';
$html_wrap_none = 'र्‌यापिङ्ग नगर्ने';
$html_usenet_separator = 'Usenet विँभाजक ("-- \n") दस्तखत अगाडि';
$html_mark_as = 'रुपमा चिनो लगाउने';
$html_read = 'पढिएको';
$html_unread = 'नपढिएको';
$html_encoding_label = 'क्यारेक्टर इन्कोडिङ्ग:';
$html_add = 'थप्ने';
$html_contacts = '%1$s सम्पर्कहरु';
$html_modify = 'सच्याउने';
$html_back = 'पछाडि';
$html_contact_add = 'नयाँ सम्पर्क थप्ने';
$html_contact_mod = 'सम्पर्क सच्याउने';
$html_contact_first = 'पहिलो नाम(नाम)';
$html_contact_last = 'अन्तिम नाम(थर)';
$html_contact_nick = 'बोलाउने नाम';
$html_contact_mail = 'इमेल';
$html_contact_list = '%1$s को सम्पर्क सुची';
$html_contact_del = 'सम्पर्क सुचीबाट';
$html_contact_count = '%1$d सम्पर्कहरु';
$html_contact_err1 = 'उच्चतम सम्पर्क संङ्ख्या "%1$d" हो';
$html_contact_err2 = 'तपाई नयाँ सम्पर्क थप्न सक्नुहुन्न';
$html_contact_err3 = 'तपाईसँग सम्पर्क सुचीको पहुच अधिकार छैन';
$html_contact_none = 'कुनैपनि सम्पर्क फेला पार्न सकिएन';
$html_del_msg = 'छानिएको सन्देशहरु मट्ने हो ?';
$html_down_mail = 'डाउनलोड गर्ने';
$original_msg = '-- मूल सन्देश --';
$to_empty = '\'लाई\'को मान खाली हुन सक्दैन';
$html_images_warning = 'सुरक्षाको लागि , दुर तस्विर देखाइएको छैन ।';
$html_images_display = 'तस्विर प्रदर्शन गर्ने';
$html_smtp_error_no_conn = ' SMTP जडान खोल्न सकिएन';
$html_smtp_error_unexpected = 'नसोचिएको SMTP प्रतिक्रिया:';
$lang_could_not_connect = 'सर्भर जडान गर्न सकिएन';
$lang_invalid_msg_num = 'खराब सन्देश संख्या';
$html_file_upload_attack = 'संभाव्य फाइल अपलोड आक्रमण';
$html_invalid_email_address = 'अमान्य इमेल ठेगाना';
$html_invalid_msg_per_page = 'अमान्य प्रति पृष्ठ सन्देशहरु';
$html_invalid_wrap_msg = 'अमान्य सन्देश र्याप';
$html_seperate_msg_win = 'सन्देशहरु फरक सञ्झ्यालमा';
$html_err_file_contacts = 'लेखनको लागि सम्पर्क फाइल खोल्न सकिएन';
$html_session_file_error = 'लेखनको लागि सत्र पाइल खोल्न सकिएन';
$html_login_not_allowed = 'यो प्रवेश सञ्जाल निर्माणको लागि मान्य छैन';
$lang_err_send_delay = 'तपाईले दुई इमेलको बीचमा (%1$d सेकेन्ड) कुर्नुपर्छ ।';
$html_search = 'खोजी';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/ne.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ne.php 2656 2015-09-10 08:37:08Z siebrand $
 */
/** Nepali (नेपाली)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Krish Dulal
 * @author RajeshPandey
 * @author राम प्रसाद जोशी
 * @author सरोज कुमार ढकाल
 */

$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'प्रवेशको मान खाली छ';
$err_passwd_empty = 'प्रवेशशब्द मान खाली छ';
$alt_delete = 'छानिएका सन्देशहरु मेट्ने';
$alt_delete_one = 'सन्देश मेट्ने';
$alt_new_msg = 'नयाँ सन्देशहरू';
$alt_reply = 'लेखकलाई जवाफ लेख्ने';
$alt_reply_all = 'सबैको जवाफलेख्ने';
$alt_forward = 'अगाडि बढाउने';
$alt_next = 'पछिको';
$alt_prev = 'अघिको';
$title_next_page = 'पछिको पृष्ठ';
$title_prev_page = 'अघिको पृष्ठ';
$title_next_msg = 'पछिको सन्देश';
$title_prev_msg = 'अघिको सन्देश';
$html_theme_label = 'विषय सार:';
$html_welcome = ' %1$s मा स्वागत छ';
$html_login = 'प्रवेश गर्ने';
$html_user_label = 'प्रयोगकर्ता :';
$html_passwd_label = 'प्रवेशशव्द:';
$html_submit = 'बुझाउने';
$html_help = 'सहायता';
$html_server_label = 'सर्भर:';
$html_wrong = 'प्रवेश या प्रवेशशव्द गलत छ';
$html_retry = 'पुन: प्रयास गर्ने';
$html_remember = 'स्थिती सम्झने';
$html_lang_label = 'भाषा:';
$html_msgperpage_label = 'प्रति पृष्ठ सन्देश:';
$html_preferences = 'अभिरुचीहरु';
$html_full_name_label = 'पूरा नाम:';
$html_email_address_label = 'इमेल ठेगाना:';
$html_bccself = 'बि सि सि प्रतिलिपि आफैलाइ';
$html_hide_addresses = 'ठेगाना लुकाउने';
$html_outlook_quoting = 'Outlook जस्तो कोटिङ्ग';
$html_reply_to = 'लाई जवाफ दिने';
$html_use_signature = 'हस्ताक्षर प्रयोग गर्ने';
$html_signature = 'हस्ताक्षर';
$html_signature_label = 'हस्ताक्षर:';
$html_reply_leadin_label = ' Leadin जवाफ लेख्ने:';
$html_prefs_updated = 'अभिरुचीहरु अध्यावधिक गरियो';
$html_manage_folders_link = ' IMAP फोल्डरहरु व्यवस्थापन गर्ने';
$html_manage_filters_link = 'ईमेल फिल्टरहरु व्यवस्तापन गर्ने';
$html_use_graphical_smilies = 'ग्राफिकल स्माइलीहरु प्रयोगगर्ने';
$html_sent_folder_label = 'पठाइएको इमेलहरु निश्चित फोल्डरमा प्रतिलिपी गर्ने';
$html_trash_folder_label = 'मेटिएका इमेलहरु निश्चित फोल्डरमा प्रतिलिपी गर्ने';
$html_colored_quotes = 'रंगाइएका कोटहरु';
$html_display_struct = 'संरचित पाठहरु देखाउने';
$html_send_html_mail = 'इमेलहरु HTML ढाँचामा पठाउने';
$html_folders = 'फोल्डरहरु';
$html_folders_create_failed = 'फोल्डर श्रृजना गर्न सकिएन !';
$html_folders_sub_failed = 'फोल्डरको ग्राह्यता प्राप्त गर्न सकिएन !';
$html_folders_unsub_failed = 'फोल्डरको ग्राह्यता बदर गर्न सकिएन !';
$html_folders_rename_failed = 'फोल्डर पुन: नामाकरण गर्न सकिएन !';
$html_folders_updated = 'फोल्षरहरु पुन: नामाकरण गरिए';
$html_folder_subscribe = 'ग्राह्यता';
$html_folder_rename = 'पुन: नामाकरण';
$html_folder_create = 'नाम गरिएको नयाँ फोल्डर श्रृजना गर्ने';
$html_folder_remove = 'बाट ग्राह्यता बदर गर्ने';
$html_folder_delete = 'मेट्ने';
$html_folder_to = 'लाई';
$html_filter_remove = 'मेट्ने';
$html_filter_body = 'सन्देश मूल भाग';
$html_filter_subject = 'सन्देश विषय';
$html_filter_to = 'लाई मान';
$html_filter_cc = 'Cc मान';
$html_filter_from = 'देखी मान';
$html_filter_change_tip = 'फिल्टर परिवर्तनको लागि अधिलेखन गर्नुहोस ।';
$html_reapply_filters = 'सबै फिल्टरको जवाफ लेख्ने';
$html_filter_contains = 'मा निहित';
$html_filter_name = 'फिल्टर नाम';
$html_filter_action = 'फिल्टर कार्य';
$html_filter_moveto = 'मा सार्ने';
$html_select_one = '--एक छान्नुहोस--';
$html_and = 'र';
$html_new_msg_in = 'नयाँ सन्देशहरू';
$html_or = 'वा';
$html_move = 'सार्ने';
$html_copy = 'प्रतिलिपी';
$html_messages_to = 'छानिएका सन्देशहरु';
$html_gotopage = 'पृष्ठमा जाने';
$html_gotofolder = 'फोल्डरमा जाने';
$html_other_folders = 'फो्डर सुची';
$html_page = 'पृष्ठ';
$html_of = 'को';
$html_view_header = 'शिर्षक प्रदर्शन गर्ने';
$html_remove_header = 'शिर्षक प्रदर्शन नगर्ने';
$html_inbox = 'पत्र मञ्जुषा';
$html_new_msg = 'लेख्ने';
$html_reply = 'जवाफ';
$html_reply_short = 'पुन:';
$html_reply_all = 'सबै जवाफ फर्काउने';
$html_forward = 'अगाडि बढाउने';
$html_forward_short = 'Fwd:';
$html_forward_info = 'अगाडि पठाएका सन्देशहरु यस सन्देशमा जोडेर पठाइने छ ।';
$html_delete = 'मेटाउने';
$html_new = 'नयाँ';
$html_mark = 'मेटाउने';
$html_att_label = 'यसमा जोडिएको:';
$html_atts_label = 'यसमा जोडिएकाहरु:';
$html_unknown = '[अज्ञात]';
$html_part_x = 'भाग %s';
$html_attach = 'जोड्ने';
$html_attach_forget = 'तपाईंको फाइल पठाउनु अघि जोड्नु पर्ने छ!';
$html_attach_delete = 'छानिएको हटाउने';
$html_attach_none = 'जोड्नको लागि कुनै फाइल छान्नु पर्छ !';
$html_sort_by = 'को आधारमा सुचीकरण';
$html_sort = 'सुचीकरण';
$html_from = 'देखि';
$html_from_label = 'देखि:';
$html_subject = 'विषय';
$html_subject_label = 'विषय:';
$html_date = 'मिति';
$html_date_label = 'मिति:';
$html_sent_label = 'पठाइएको:';
$html_wrote = 'लेख्नु भएको थियो';
$html_size = 'आकार';
$html_totalsize = 'पूरा आकार';
$html_kb = 'केबि';
$html_mb = 'एमबि';
$html_gb = 'जिबि';
$html_bytes = 'बाइटहरू';
$html_filename = 'फाइल नाम';
$html_to = 'लाई';
$html_to_label = 'लाई:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'विषय बिना';
$html_send = 'पठाउने';
$html_cancel = 'बदर गर्ने';
$html_no_mail = 'सन्देश बिना।';
$html_logout = 'बाहिरिने';
$html_msg = 'सन्देश';
$html_msgs = 'सन्देशहरु';
$html_configuration = 'यो सर्भर राम्ररी मिलाइएको छैन !';
$html_priority = 'प्राथमिकता';
$html_priority_label = 'प्राथमिकता:';
$html_lowest = 'अति न्युन';
$html_low = 'न्युन';
$html_normal = 'सामान्य';
$html_high = 'उच्च';
$html_highest = 'अति उच्च';
$html_flagged = 'फ्ल्याग गरिएको';
$html_spam = 'स्प्याम';
$html_spam_warning = 'यस संदेश लाइ स्प्याम को रूप मा वर्गीकृत गरिएको छ।';
$html_receipt = 'फिर्ते रसिदको लागि अनुरोध गर्ने';
$html_select = 'छान्ने';
$html_select_all = 'छानिएको उल्ट्याउने';
$html_select_contacts = 'सम्पर्क छान्ने';
$html_loading_image = 'तस्विर लोड गर्दै';
$html_send_confirmed = 'तपाईंको इमेल प्रेषणको लागि स्विकारिएको छ';
$html_no_sendaction = 'कुनै पनि कार्य खुलाइएको छैन । जाभा स्क्रिप्ट सक्षम पार्नुहोस् ।';
$html_error_occurred = 'एक त्रुटि भयो ।';
$html_prefs_file_error = 'अभीरुची फाइलहरू लेखनको लागि खोल्न असमर्थ ।';
$html_wrap = 'पठाउन लागिएको सन्देशमा र्‌याप गर्नुपर्ने क्यारेक्टरहरु :';
$html_wrap_none = 'र्‌यापिङ्ग नगर्ने';
$html_usenet_separator = 'Usenet विँभाजक ("-- \n") दस्तखत अगाडि';
$html_mark_as = 'रुपमा चिनो लगाउने';
$html_read = 'पढिएको';
$html_unread = 'नपढिएको';
$html_encoding_label = 'क्यारेक्टर इन्कोडिङ्ग:';
$html_add = 'थप्ने';
$html_contacts = '%1$s सम्पर्कहरु';
$html_modify = 'सच्याउने';
$html_back = 'पछाडि';
$html_contact_add = 'नयाँ सम्पर्क थप्ने';
$html_contact_mod = 'सम्पर्क सच्याउने';
$html_contact_first = 'पहिलो नाम(नाम)';
$html_contact_last = 'अन्तिम नाम(थर)';
$html_contact_nick = 'बोलाउने नाम';
$html_contact_mail = 'इमेल';
$html_contact_list = '%1$s को सम्पर्क सुची';
$html_contact_del = 'सम्पर्क सुचीबाट';
$html_contact_count = '%1$d सम्पर्कहरु';
$html_contact_err1 = 'उच्चतम सम्पर्क संङ्ख्या "%1$d" हो';
$html_contact_err2 = 'तपाईं नयाँ सम्पर्क थप्न सक्नुहुन्न';
$html_contact_err3 = 'तपाईंसँग सम्पर्क सूचीको पहुच अधिकार छैन';
$html_contact_none = 'कुनैपनि सम्पर्क फेला पार्न सकिएन';
$html_del_msg = 'छानिएको सन्देशहरु मट्ने हो ?';
$html_down_mail = 'डाउनलोड गर्ने';
$original_msg = '-- मूल सन्देश --';
$to_empty = '\'लाई\'को मान खाली हुन सक्दैन';
$html_images_warning = 'सुरक्षाको लागि , दुर तस्विर देखाइएको छैन ।';
$html_images_display = 'तस्विर प्रदर्शन गर्ने';
$html_smtp_error_no_conn = ' SMTP जडान खोल्न सकिएन';
$html_smtp_error_unexpected = 'नसोचिएको SMTP प्रतिक्रिया:';
$lang_could_not_connect = 'सर्भर जडान गर्न सकिएन';
$lang_invalid_msg_num = 'खराब सन्देश संख्या';
$html_file_upload_attack = 'संभाव्य फाइल अपलोड आक्रमण';
$html_invalid_email_address = 'अमान्य इमेल ठेगाना';
$html_invalid_msg_per_page = 'अमान्य प्रति पृष्ठ सन्देशहरु';
$html_invalid_wrap_msg = 'अमान्य सन्देश र्याप';
$html_seperate_msg_win = 'सन्देशहरु फरक सञ्झ्यालमा';
$html_err_file_contacts = 'लेखनको लागि सम्पर्क फाइल खोल्न सकिएन';
$html_session_file_error = 'लेखनको लागि सत्र पाइल खोल्न सकिएन';
$html_login_not_allowed = 'यो प्रवेश सञ्जाल निर्माणको लागि मान्य छैन';
$lang_err_send_delay = 'तपाईंले दुई इमेलको बीचमा (%1$d सेकेन्ड) कुर्नुपर्छ ।';
$html_search = 'खोजी';
